# About ts-scan

***ts-scan*** is the latest scanner we developed. In the early stages, we developed scanners per each development environment. But soon we got overwhelmed with all the update requirements since all ecosystems tend to evolve. In addition our customers kept asking us for integration of here and there and not all supporters kept with the command definitions leading to different command sets...

To make a long story short, having one tool covering all different ecosystems with a plugin mechanism allowing to add more ecosystems seems much simpler to maintain. Here we are: [ts-scan](https://github.com/trustsource/ts-scan).



## About TrustSource

[TrustSource](https://www.trustsource.io) is a brand representing a [SaaS-solution](https://app.trustsource.io) that supports companies to cope with all sort of regulations to comply with when developing and distributing software, such as [ISO/IEC 5230](https://www.iso.org/obp/ui/en/#iso:std:iso-iec:5230:ed-1:v1:en) (OpenChain on Oopen source compliance),  [ISO/IEC 18974](https://www.iso.org/standard/86450.html) (Open Source Security Assurance) or the [Cyber Resilience Act](https://digital-strategy.ec.europa.eu/en/library/cyber-resilience-act) (CRA) introduced by the European Union in October 2024. 

While the platform is provided as a managed service, the scanners as well as the core itself are available as open source solutions. You may use it to self host the  



## About EACG 

[EACG](https://www.eacg.de) is the company behind TrustSource. EACG is an enterprise architecture consulting company, that has started the endavour in 2014. EACG supports its clients with design and delivery of digital business models. Explorationa and relisation of the prototypes and development of the first business units are part of their eingagement. This very early lead to the question of licenses and ownership. 

Based on the experiences how fast a wrong license may enter the repository automated SBOM creation has been invented before even the SBOM became a dominating slogan. Vulnerbaility management has been added 2018 as a logical consequence, the service started to become interesting to others... 



## About EACG Operations Services

EACG decided to hand the operations of the platform to its AWS operations subsidiary. Thus EACG OS is taking care to run and manage the platform as well as the provisioning of support services while EACG is taking care for the individual consulting services. You may find further information on the [EACG website](https://www.eacg.de). Find here links to further information:

* [General terms and conditions](https://www.trustsource.io/terms/), 
* our [privacy policy](https://www.trustsource.io/privacy-policy/),
* the [security policy](https://www.trustsource.io/security-policy),
* the [shared security responsibility model](https://trustsource.github.io/SSRM), 
* our [knowledge base](https://support.trustsource.io) 
* the [service status information](https://trustsource.statuspage.io) 



